@@ -1,6 +1,5 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	rxvtgrx.h
- * $Id: rxvtgrx.h,v 1.3 1999/12/30 05:42:36 mason Exp $
  *
  * Stuff for text alignment for rxvt special graphics mode
  *
@@ -11,7 +10,7 @@
  * Center:
  *	text is placed so that the specified point is equidistant from the
  *	bottom of descenders and the top of the capital letters
- * Bottom:
+ * Botton:
  *	text is placed so that the bottom of descenders is on the specified
  *	point
  * Base:
@@ -21,8 +20,8 @@
  *	text is placed so that the specified point is equidistant from the
  *	bottom and tops of capital letters
  *----------------------------------------------------------------------*/
-#ifndef _RXVTGRX_H_
-#define _RXVTGRX_H_
+#ifndef _RXVTGRX_H
+#define _RXVTGRX_H
 
 #define GRX_SCALE		10000
 
@@ -39,16 +38,16 @@
 #define VERTICAL_ALIGNMENT	0x0F
 
 #if 0	/* this would be nicer */
-# define TXT_RIGHT		'r'
-# define TXT_CENTER		'c'
-# define TXT_LEFT		'l'
+#define TXT_RIGHT		'r'
+#define TXT_CENTER		'c'
+#define TXT_LEFT		'l'
 
-# define TXT_TOP		't'
-# define TXT_VCENTER		'v'
-# define TXT_BOTTOM		'b'
-# define TXT_BASE		'_'
-# define TXT_VCAPS_CENTER	'C'
+#define TXT_TOP			't'
+#define TXT_VCENTER		'v'
+#define TXT_BOTTOM		'b'
+#define TXT_BASE		'_'
+#define TXT_VCAPS_CENTER	'C'
 #endif
 
-#endif /* _RXVTGRX_H_ */
+#endif	/* whole file */
 /*----------------------- end-of-file (C header) -----------------------*/
